@@ -1,3 +1,5 @@
+from datetime import timedelta
+
 import pyspark.sql.functions as f
 from pyspark.sql import DataFrame
 
@@ -9,7 +11,7 @@ from atc.etl.extractors.simple_extractor import Readable
 class IncrementalExtractor(Extractor):
     """This extractor will extract from any object that has a .read() method.
     Furthermore, it will use a target table for enabling incremental extraction.
-
+    If needed it's possible to define a overlapping period using the timedelta function.
     NB: It is not recommended to use this on Eventhub data.
         Use EventHubCaptureExtractor instead.
 
@@ -22,12 +24,14 @@ class IncrementalExtractor(Extractor):
         time_col_source: str,
         time_col_target: str,
         dataset_key: str = None,
+        overlap_period: timedelta = None,
     ):
         super().__init__(dataset_key=dataset_key)
         self.handle_source = handle_source
         self.handle_target = handle_target
         self._timecol_source = time_col_source
         self._timecol_target = time_col_target
+        self._overlap_period = overlap_period
 
     def read(self) -> DataFrame:
         if isinstance(self.handle_source, EventHubCapture):
@@ -46,6 +50,10 @@ class IncrementalExtractor(Extractor):
             df_target.groupBy().agg(f.max(self._timecol_target)).collect()[0][0]
         )
 
+        # If overlap_period is defined extract it from target_max_time
+        if self._overlap_period:
+            target_max_time = target_max_time - self._overlap_period
+
         # If the target table is empty, target_max_time will be None
         # Only filter the input dataframe if the table is non-empty
         # table non-empty = target_max_time not None
